/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import iCal, { CalendarResponse } from 'node-ical';
import { Api } from '../base/Api';
import { SoftConfig } from '../config/SoftConfig';
import { Cache } from '../utils/Cache';

class AdeApiManager extends Api {
    constructor() {
        super();
        SoftConfig.registerConfig('ade.url');
    }

    async export(projectId: number, resources: number[], calType: string, nbWeeks: number) {
        const res = await this.request(
            'GET',
            SoftConfig.get('ade.url', '').replace(/\/$/, '') +
                '/jsp/custom/modules/plannings/anonymous_cal.jsp' +
                '?projectId=' +
                projectId +
                '&resources=' +
                resources.join(',') +
                '&calType=' +
                calType +
                '&nbWeeks=' +
                nbWeeks
        );

        if (!res.good) {
            throw new Error(res.error);
        }

        return res.data;
    }

    async load_events(projectId: number, resources: number[], nbWeeks: number): Promise<CalendarResponse> {
        return await iCal.async.parseICS(await this.export(projectId, resources, 'ics', nbWeeks));
    }

    async used_rooms_at(date: Date) {
        let out: string[] = [];
        const rooms: CalendarResponse = await Cache.cache('ade.rooms', 12 * 3600, async () => await this.load_events(7, [30658, 30678], 4));

        for (const [, room] of Object.entries(rooms)) {
            if (room.type === 'VEVENT') {
                if (date > new Date(room.start) && date < new Date(room.end)) {
                    out = out.concat(room.location);
                }
            }
        }

        // Remove duplicates
        return [...new Set(out)];
    }
}

export const AdeApi = new AdeApiManager();
