/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import { Api } from '../base/Api';
import { SoftConfig } from '../config/SoftConfig';
import { Cache } from '../utils/Cache';

class CrousApiManager extends Api {
    constructor() {
        super();
        SoftConfig.registerConfig('crous.menu.url');
    }

    async load_menu(region: number, restaurant: number) {
        return await this.request('GET', `https://webservices-v2.crous-mobile.fr:8443/ws/v1/regions/${region}/restaurants/${restaurant}/menus/`);
    }

    async menu(region: number, restaurant: number) {
        return await Cache.cache(`crous.menu.${region}.${restaurant}`, 3600, async () => {
            const menu = await this.load_menu(region, restaurant);
            if (!menu.good) {
                Promise.reject();
            } else {
                return menu.data;
            }
        });
    }
}

export const CrousApi = new CrousApiManager();
