/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import { GetProfileRequest } from '@amicale-core/seb-ts';
import { CommandInteraction } from 'discord.js';
import { Command } from '../base/Command';
import { Bot } from '../Bot';
import { I18n } from '../utils/I18n';

export class CheckCommand extends Command {
    constructor() {
        super();
    }

    getName() {
        return 'check';
    }

    getConfigs() {
        return [];
    }

    isReservedToGod() {
        return true;
    }

    isDevCommand() {
        return true;
    }

    async execute(interaction: CommandInteraction) {
        await interaction.deferReply({ ephemeral: true });
        const profile_req = new GetProfileRequest(Bot.getRest());
        const profile = (await profile_req.make()).data;

        let message = '';
        message += I18n.formatI18n('command.check.reply.connected', interaction.locale, {
            firstname: profile.firstname,
            lastname: profile.lastname,
            username: profile.username
        }) + "\n";
        message += I18n.getI18n('command.check.reply.permissions', interaction.locale)
        message += profile.permissions.map((e) => {
            return '`' + e + '`';
        }).join(', ');

        interaction.editReply({ content: message });
    }
}
