/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import { ExportPersonRequest, GetPeopleRequest } from '@amicale-core/seb-ts';
import { APIApplicationCommandOption, ApplicationCommandOptionType } from 'discord-api-types/v9';
import { CommandInteraction, MessageAttachment } from 'discord.js';
import { Readable } from 'stream';
import { Command } from '../base/Command';
import { Bot } from '../Bot';
import { SoftConfig } from '../config/SoftConfig';
import { I18n } from '../utils/I18n';

export class GDPRCommand extends Command {
    private sub: { [index: string]: (interaction: CommandInteraction) => Promise<void> };

    constructor() {
        super();
        this.sub = {
            export: this.exec_export,
            policy: this.exec_policy,
        };
    }

    getName() {
        return 'gdpr';
    }

    getOptions(): APIApplicationCommandOption[] {
        return [
            {
                type: ApplicationCommandOptionType.Subcommand,
                ...I18n.argumentI18n(this, 'export')
            },
            {
                type: ApplicationCommandOptionType.Subcommand,
                ...I18n.argumentI18n(this, 'policy')
            },
        ];
    }

    async exec_policy(interaction: CommandInteraction) {
        const file = new MessageAttachment(SoftConfig.get('seb.url', '') + 'doc/privacy-policy.pdf');
        await interaction.reply({ files: [file], ephemeral: true });
    }

    async exec_export(interaction: CommandInteraction) {
        await interaction.deferReply({ ephemeral: true });
        const people_req = new GetPeopleRequest(Bot.getRest(), { query: { filter: { discord_id: interaction.user.id } } });
        const people = (await people_req.make()).data;

        if (people.length <= 0) {
            await interaction.editReply({ content: I18n.getI18n('error.notregistered', interaction.locale) });
            return;
        }

        const export_req = new ExportPersonRequest(Bot.getRest(), people[0].id);
        const exp = (await export_req.make()).data;

        const stream = new Readable();
        stream.push(JSON.stringify(exp));
        stream.push(null);
        const file = new MessageAttachment(stream, 'export.json');
        await interaction.editReply({ content: I18n.getI18n('command.gdpr.export.reply', interaction.locale), files: [file] });
    }

    async execute(interaction: CommandInteraction) {
        await this.sub[interaction.options.getSubcommand()](interaction);
    }
}
