/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import { GetProductCategoriesRequest, GetProductsRequest } from '@amicale-core/seb-ts';
import { CommandInteraction, MessageAttachment, MessageEmbed } from 'discord.js';
import { Command } from '../base/Command';
import { Bot } from '../Bot';
import { SoftConfig } from '../config/SoftConfig';
import { Cache } from '../utils/Cache';
import { Emoji } from '../utils/Emoji';
import { I18n } from '../utils/I18n';

export class StocksCommand extends Command {
    constructor() {
        super();
    }

    getName() {
        return 'stocks';
    }

    getConfigs() {
        return ['bot.color'];
    }

    async execute(interaction: CommandInteraction) {
        const attachment = new MessageAttachment('./resources/seb.png');

        await interaction.deferReply();
        const products_categories = await Cache.cache('seb.products_categories', 60, async () => {
            const products_cat_req = new GetProductCategoriesRequest(Bot.getRest());
            return (await products_cat_req.make()).data;
        });
        const products = await Cache.cache('seb.products', 60, async () => {
            const products_req = new GetProductsRequest(Bot.getRest());
            return (await products_req.make()).data;
        });

        let embed = new MessageEmbed()
            .setColor(SoftConfig.get('bot.color', '#fb963a'))
            .setTitle(I18n.getI18n('command.stocks.reply.title', interaction.locale))
            .setTimestamp(Cache.modified_date('seb.products'))
            .setThumbnail('attachment://seb.png');

        for (const category of products_categories) {
            const pstring = products
                .filter((p) => p.category_id === category.id && p.salable)
                .map((product) => {
                    if (product.count <= 0) return `${Emoji.null} ${product.name}`;
                    else if (product.count <= 10 && product.count <= product.alert_level) return `${Emoji.digitToEmoji(product.count)} ${product.name}`;
                    else return `${Emoji.yes} ${product.name}`;
                })
                .join('\n');

            if (pstring !== '') embed = embed.addField(category.name, pstring, false);
        }

        interaction.editReply({ embeds: [embed], files: [attachment] });
    }
}
