/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import { GetPeopleRequest } from '@amicale-core/seb-ts';
import { CommandInteraction } from 'discord.js';
import { Command } from '../base/Command';
import { Bot } from '../Bot';
import { I18n } from '../utils/I18n';

export class WhoamiCommand extends Command {
    constructor() {
        super();
    }

    getName() {
        return 'whoami';
    }

    async execute(interaction: CommandInteraction) {
        await interaction.deferReply({ ephemeral: true });

        const people_req = new GetPeopleRequest(Bot.getRest(), { query: { filter: { discord_id: interaction.user.id } } });

        try {
            const people = (await people_req.make()).data;

            if (people.length <= 0) {
                await interaction.editReply({ content: I18n.getI18n("command.whoami.reply.notreg", interaction.locale) });
            } else {
                const d = people[0];
                interaction.editReply({ content: `${I18n.getI18n("command.whoami.reply.reg", interaction.locale)}\n#${d.id} - ${d.fullname}` });
            }
        } catch (e) {
            await interaction.editReply({ content: I18n.getI18n("command.whoami.reply.error", interaction.locale) });
        }
    }
}
