/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import { GetMembersRequest, GetPeopleRequest, PersonData } from '@amicale-core/seb-ts';
import { Message } from 'discord.js';
import _ from 'lodash';
import { DMCommand } from '../base/DMCommand';
import { Bot } from '../Bot';
import { SoftConfig } from '../config/SoftConfig';
import { Messages } from '../utils/Messages';

export class MembersCheckDMCommand extends DMCommand {
    constructor() {
        super();
    }

    getName() {
        return 'members check';
    }

    getDescription() {
        return "Liste les gens à inviter sur le Discord de l'amicale.";
    }

    getArgumentsRegex() {
        return '';
    }

    async execute(message: Message, content: string, args: string[]): Promise<void> {
        const server = await message.client.guilds.cache.get(SoftConfig.get('discord.guildid', ''));
        const server_members = await server?.members.fetch();

        const peolpe_req = new GetPeopleRequest(Bot.getRest());
        const members_req = new GetMembersRequest(Bot.getRest());

        const seb_people = (await peolpe_req.make()).data;
        const seb_members = (await members_req.make()).data;

        const people = [];

        for (const seb_member of seb_members) {
            if (seb_member.payed) {
                const person = _.find(seb_people, { id: seb_member.person_id }) as PersonData | undefined;

                if (server_members?.get(person?.discord_id + '') === undefined) {
                    people.push(' - ' + person?.fullname + ' <@' + person?.discord_id + '>');
                }
            }
        }

        if (people.length === 0) {
            message.reply('Personne à inviter.');
        } else {
            Messages.sendSplittedReply(message, 'Liste des gens à inviter: \n' + people.join('\n'));
        }
    }
}
