/**
 * Copyright © 2021 Maxime Friess <M4x1me@pm.me>
 *
 * This file is part of Seb-BOT.
 *
 * Seb-BOT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Seb-BOT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Seb-BOT.  If not, see <https://www.gnu.org/licenses/>.
 */

import { GetStatsRequest } from '@amicale-core/seb-ts';
import { GitlabApi } from '../api/GitlabApi';
import { Bot } from '../Bot';
import { Cache } from './Cache';

class Facts {
    private facts: Array<() => Promise<string>>;

    constructor() {
        this.facts = [];

        const s = async () =>
            (
                await Cache.cache('seb.stats', 300, async () => {
                    const stat_req = new GetStatsRequest(Bot.getRest());
                    return await stat_req.make();
                })
            ).data;
        const g = async () => (await Cache.cache('gitlab.project', 300, () => GitlabApi.project())).data;

        this.registerFact(async () => `K achète ses gateaux à l'amicale...`);
        this.registerFact(async () => `${(await s()).sold_coffee_liters}L de cafés ont été vendus depuis la création de Seb™.`);
        this.registerFact(async () => `Le produit le plus vendu est: ${(await s()).most_sold_product}.`);
        this.registerFact(async () => `Un grand fou a dépensé ${new Number((await s()).biggest_sale).toFixed(2)}€ d'un coup à l'Amicale.`);
        this.registerFact(async () => `${(await s()).sold_water_bottles} pigeons ont acheté des bouteilles d'Eau... Alors qu'on a des robinets.`);
        this.registerFact(async () => {
            const days_since_restock = Math.floor((Date.now() - Date.parse((await s()).latest_restock)) / (24 * 60 * 60 * 1000));
            if (days_since_restock === 0) {
                return "Les courses ont été faites aujourd'hui.";
            } else if (days_since_restock === 1) {
                return 'Les courses ont été faites hier.';
            } else {
                return `Les courses ont été faites il y a ${days_since_restock} jours.`;
            }
        });
        this.registerFact(async () => `${(await s()).sold_bounties} bounties ont ont été vendus depuis la création de Seb™ (Merci EW. ^^).`);
        this.registerFact(async () => `${(await s()).most_sales} a vendu le plus de produits.`);
        this.registerFact(async () => `${(await s()).members} personnes ont généreusement contribué à la survie de l'amicale cette année 💜`);
        this.registerFact(async () => `L'amicale est ${Math.floor((1 - (await s()).price_coca / 0.8) * 100)}% moins chère que les distributeurs.`);

        this.registerFact(async () => `Seb™ a été créé il y a ${this.date_diff(Date.parse((await g()).created_at))}.`);
        this.registerFact(async () => `${(await g()).star_count} personnes ont laché une étoile sur le repo de Seb™: <${(await g()).web_url}> 👀`);
    }

    private date_diff(date: number) {
        const diff = Math.floor(Date.now() - date);
        const day = 1000 * 60 * 60 * 24;

        const days = Math.floor(diff / day) % 31;
        const months = Math.floor(diff / day / 31) % 12;
        const years = Math.floor(diff / day / 31 / 12);

        let message = years + ' années, ';
        message += months + ' mois et ';
        message += days + ' jours';

        return message;
    }

    registerFact(fact: () => Promise<string>) {
        this.facts.push(fact.bind(this));
    }

    async getRandomFact(): Promise<string> {
        return await this.facts[Math.floor(Math.random() * this.facts.length)]();
    }
}

export default new Facts();
